﻿#region Copyright
/// <summary>The ScummVM WPF UI project</summary>
/// <copyright>(c) 2016 MojoTouch</copyright>
/// <author>Ilya Rovensky</author>
#endregion

using System;
using System.Diagnostics;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;

namespace WpfInterface
{
    public partial class MainMenu : Menu
    {
        private string _urlToPromote;

        public MainMenu(int menuState, GameType gameToPromote, string urlToPromote) : base(menuState)
        {
            InitializeComponent();
            SaveButton.IsEnabled = State.IsSaveEnabled;
            LoadButton.IsEnabled = State.IsLoadEnabled;
            ContinueButton.IsEnabled = State.IsContinueEnabled;
            if (ContinueButton.IsEnabled)
            {
                ContinueButton.Focus();
            }
            else if (NewGameButton.IsEnabled)
            {
                NewGameButton.Focus();
            }

#if TARGET_SIMON1 || TARGET_SIMON2 || TARGET_FOTAQ
            ExtrasButton.Visibility = Visibility.Collapsed;
#elif TARGET_T7G
            ExtrasButton.Visibility = Visibility.Collapsed;
            
            if (State.IsOpenHouseEnabled)
            {
                Log("MainMenu: Open House Mode is enabled.");
                OpenHouseButton.Visibility = Visibility.Visible;
            }
            else
            {
                Log("MainMenu: Open House Mode is disabled.");
                OpenHouseButton.Visibility = Visibility.Collapsed;
            }
#elif TARGET_FOTAQ
            uniformGrid.RowDefinitions.Add(new RowDefinition());
            Grid.SetRow(QuitButton, 4);
            Grid.SetColumn(QuitButton, 0);
            Grid.SetColumnSpan(QuitButton, 2);
            Grid.SetRow(ExtrasButton, 3);            
#endif
            TutorialButton.IsEnabled = State.HasTutorial;
            ExtrasButton.IsEnabled = State.HasExtras;

            string gamePath = null;
            _urlToPromote = urlToPromote;

            switch (gameToPromote)
            {
                case GameType.Simon1:
                    gamePath = "Simon1";
                    break;
                case GameType.Simon2:
                    gamePath = "Simon2";
                    break;
                case GameType.Fotaq:
                    gamePath = "FOTAQ";
                    break;
                case GameType.T7G:
                    gamePath = "T7G";
                    break;
            }

            if (gamePath != null)
                AdButton.Content = new Image()
                {
                    Source = new BitmapImage(new Uri(BaseUriHelper.GetBaseUri(this), $"Assets/{gamePath}/Icon/icon.png")),
                    Width = 32,
                    Height = 32
                };
            else
            {
#if TARGET_SIMON1 || TARGET_SIMON2
                Grid.SetColumn(QuitButton, 0);
                Grid.SetColumnSpan(QuitButton, 2);
#endif
                AdButton.Visibility = Visibility.Collapsed;
            }

            //Remove Tutorial from all games (and set Ad and Quit buttons accordingly)
            TutorialButton.Visibility = Visibility.Collapsed;
            AdButton.Visibility = Visibility.Visible;
#if TARGET_SIMON1 || TARGET_SIMON2
            Grid.SetColumn(AdButton, 1);
            Grid.SetRow(AdButton, 2);
            Grid.SetColumnSpan(AdButton, 2);
#elif TARGET_T7G
            Grid.SetColumn(AdButton, 2);
            Grid.SetRow(AdButton, 2);
            Grid.SetColumnSpan(AdButton, 1);
#elif TARGET_FOTAQ
            Grid.SetColumn(AdButton, 1);
            Grid.SetRow(AdButton, 2);
#endif

#if TARGET_SIMON1 || TARGET_T7G || TARGET_FOTAQ
            Grid.SetColumn(QuitButton, 0);
            Grid.SetColumnSpan(QuitButton, 2);
#endif  
        }

        protected override void StringsChanged()
        {
            NewGameButton.Content = Strings[(int)LocString.new_game];
            ContinueButton.Content = Strings[(int)LocString.continue_];
            SaveButton.Content = Strings[(int)LocString.save_game];
            SettingsButton.Content = Strings[(int)LocString.settings];
            LoadButton.Content = Strings[(int)LocString.load_game];
            TutorialButton.Content = Strings[(int)LocString.tutorial];
            QuitButton.Content = Strings[(int)LocString.quit];
            ExtrasButton.Content = Strings[(int)LocString.extras];
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            SetResultFromSenderTag((FrameworkElement)sender);
        }

        private void AdButton_Click(object sender, RoutedEventArgs e)
        {
            // opens URL in browser
            if (!string.IsNullOrEmpty(_urlToPromote))
            {
                SoundPlayer.Music(false);
                Process.Start(_urlToPromote);
            }
        }
    }
}
